// Kururin Gauge
// Jonathan Jamieson (unigamer@gmail.com)
// www.jonathanjamieson.com/kururin
// This file is for those who want to understand how the was made and perhaps modify it. If you just want a Kururin Gauge then this isn't the file you're looking for! Pre-prepared files have been made in PDF and DXF format. They are available from the website above.
// If you have any suggestions, questions, complaints or nice things to say then send me an email :)

// Measurements
kururinLength = 90; // The Comcell Kururin's are 90mm

// Parameters that may be of use (and can be changed without breaking things to much!)
kerfSize = 0; // Currently the kerf is accounted for but untested in real life. 
padFraction = 0.85; // Use the circular hole as a guide for cutting the end-pads.

// Parameters that relate to the curve profile stored in the DXF file.
// Chances are that if any of these are changed they all need to be changed.
lengthOfImportedCurve = 90;
bendRadius = 3.5;
kururinMiddleDiameter = 0.3*kururinLength;
kururinEndDiameter = (20/90)*kururinLength;
kururinCurveDXFFile = "kururinStandardProfile.dxf";

// Calculated Parameter
kururinHalfLength = kururinLength/2;

difference() {
    baseRectangle();
    translate([(kururinLength+2*kerfSize)/4.3,0,0]) middleDiameterCutout();
    translate([(kururinLength+2*kerfSize)/1.7,0,0]) endDiameterCutout();
    translate([(kururinLength+2*kerfSize)/1.18,kururinMiddleDiameter/3+(kururinMiddleDiameter/2-padFraction*kururinEndDiameter/2),0]) scalpelGuide();
    //translate([(kururinLength+2*kerfSize)/2.3,kururinHalfLength/2]) compassGuide(); // This is a test feature for compass cutter. Currently does not work.
    translate([kerfSize,kururinHalfLength+2*kerfSize,0]) profile();
}

module baseRectangle() {
    square([kururinLength+2*kerfSize,kururinHalfLength+2*kerfSize]);
}

module middleDiameterCutout() {  
    translate([-(kururinMiddleDiameter-2*kerfSize)/2,0,0])   square([kururinMiddleDiameter-2*kerfSize,kururinMiddleDiameter/3]);
    translate([0,kururinMiddleDiameter/3,0])   circle(d=kururinMiddleDiameter-2*kerfSize,$fn=50);
}


module endDiameterCutout() {    
    translate([-(kururinEndDiameter-2*kerfSize)/2,0,0])   square([kururinEndDiameter-2*kerfSize,kururinEndDiameter/3]);
    translate([0,kururinEndDiameter/3,0])   circle(d=kururinEndDiameter-2*kerfSize,$fn=50);
}

module scalpelGuide() {    
    circle(d=padFraction*kururinEndDiameter,$fn=50);    
}

module compassGuide() {
    circle(d=1.6,$fn=50);
    translate([padFraction*kururinEndDiameter,-7.8/2,0]) square([0.3,7.8]);  
}

module profile() {  
    scale([kururinLength/lengthOfImportedCurve,kururinLength/lengthOfImportedCurve,00]) import (file = kururinCurveDXFFile);   
}