// Kururin Sanding Jig
// Jonathan Jamieson (unigamer@gmail.com)
// www.jonathanjamieson.com/kururin
// This model is used when sanding the ends of a Kururin on a disc sander. Without this, or something similar, it is very hard to get the ends right.
// If you have any suggestions, questions, complaints or nice things to say then send me an email :)

// Measurements
kururinLength = 90; // The Comcell Kururin's are 90mm (300mm doesn't work?)

// Parameters that may be of use (and can be changed without breaking things to much!)
kerfSize = 0; // Currently the kerf is accounted for but untested in real life. 
padFraction = 0.85; // Use the circular hole as a guide for cutting the end-pads.
extrudeQuality = 200;
textThickness = 1;
textSize = 3;

// Parameters that relate to the curve profile stored in the DXF file.
// Chances are that if any of these are changed they all need to be changed.
lengthOfImportedCurve = 90;
bendRadius = 3.5;
kururinMiddleDiameter = 0.3*kururinLength;
kururinEndDiameter = (20/90)*kururinLength;
kururinCurveDXFFile = "kururinStandardProfile.dxf";

// Calculated Parameter
kururinHalfLength = kururinLength/2;
kururinBendRadius = bendRadius*(kururinLength/lengthOfImportedCurve);

blockLength = 0.9*kururinLength;
blockWidth = 2*kururinMiddleDiameter;
blockHeight = 0.6*kururinMiddleDiameter;

translate([0,0,blockHeight/2]) jig(); // jig(1); shows the Kururin in place
//kururin3DModel();

module jig(kururinPresent) {
    difference() { 
    translate([-blockLength/2,-blockWidth/2,-blockHeight/2])cube([blockLength,blockWidth,blockHeight]);   
    color("pink") translate([0,0,blockHeight/2]) kururin3DModelRotated();
    color("red") translate([0,(kururinMiddleDiameter/2+blockWidth/2)/2,blockHeight/2-textThickness]) kururinText();   
}

    if (kururinPresent == 1) { // This is used for demonstration, not practical purposes.
    color("pink", 0.9 )  translate([0,0,blockHeight/2])kururin3DModelRotated();
    }
}

module kururin3DModelRotated() {
    rotate([0,90,0]) translate([0,0,-kururinHalfLength])  kururin3DModel();    
}

module kururin3DModel() {
    rotate_extrude($fn=extrudeQuality) rotate([0,0,90]) translate([0,-kururinMiddleDiameter/2+kururinBendRadius,0]) profile();    
}

module profile() {  
    scale([kururinLength/lengthOfImportedCurve,kururinLength/lengthOfImportedCurve,0]) import (file = kururinCurveDXFFile);   
}

module kururinText() {   
    translate([0,3*(kururinLength/lengthOfImportedCurve),0])    linear_extrude(height = textThickness) text("Kururin Sanding Jig", font = "EngraversGothic BT",halign = "center", valign = "center", size=textSize*(kururinLength/lengthOfImportedCurve), spacing=1.1);
    
    translate([0,0.0*(kururinLength/lengthOfImportedCurve),0]) linear_extrude(height = textThickness) text("jonathanjamieson.com", font = "EngraversGothic BT",halign = "center", valign = "center", size=textSize*(kururinLength/lengthOfImportedCurve), spacing=1.1);
    
    translate([0,-3*(kururinLength/lengthOfImportedCurve),0]) linear_extrude(height = textThickness) text(str(kururinLength,"mm"), font = "EngraversGothic BT",halign = "center", valign = "center", size=0.7*textSize*(kururinLength/lengthOfImportedCurve), spacing=1.1);
}